@@ -1,6 +1,6 @@
 # Helper for process handling - fancy wrapper around subprocess
 
-import time, sys, os
+import time
 import subprocess as sp
 
 from amz.loading import Loading
@@ -17,11 +17,10 @@ def classify_cmds(command):
     if cmd_prefix == 'pyx>':
         return 1, command[4:]
     # Check Re-sudo command
-    elif cmd_prefix == 'rsu>':
+    if cmd_prefix == 'rsu>':
         return 2, command[4:]
     # Else it's a normal command
-    else:
-        return 0, command
+    return 0, command
 
 
 def run_cmd(command, name='', prestr='', verbose=False):
@@ -41,7 +40,7 @@ def run_cmd(command, name='', prestr='', verbose=False):
     elif cmd_type == 2:
         p = sp.run(f"sudo -p '{prestr}Need [sudo] access again: ' echo '{prestr}Thanks!'", shell=True)
         l.end(0)
-    elif cmd_type == -1:
+    else:  # cmd_type == -1:
         print(f"Invalid Command - {command}")
 
     # Give some rest
